@@ -62,7 +62,7 @@ class web:
 
         name: python命令行解释机名字
         """
-        if '--web' in sys.argv or True:
+        if 'eventlog' in sys.argv or len(sys.argv)==1:
             filename=sys.argv[0][:-3]
             if self.__config.app['app_debug']:
                 arg=sys.argv
@@ -200,7 +200,7 @@ class web:
         param=[]
         urls=''
         i=0
-        HTTP_HOST=header['HTTP_HOST'].split(".")[0]
+        # HTTP_HOST=header['HTTP_HOST'].split(".")[0]
         ##默认路由start #################################################################################
         
         if modular:
@@ -331,6 +331,7 @@ class web:
         if PATH_INFO[0]==' ' or PATH_INFO[0]=='':
             del PATH_INFO[0]
         methods,modular,plug,files,funct,param=web.defaultroute(self,header,PATH_INFO)
+        globals.VAR.component=(methods,modular,plug,files,funct,param)
         if header['REQUEST_METHOD'] in methods:
             try:
                 obj=getattr(web.__appname,modular)
