@@ -6,7 +6,7 @@ app['tpl_folder']='./tpl'  #设置模板文件目录名 注意：不能配置目
 app['before_request']=''  #设置请求前执行的函数
 app['after_request']=''    #设置请求后执行的函数  
 app['staticpath']='static'
-app['http_server']='kcweb_server' #使用的开发服务器 支持 wsgiref、kcweb、kcweb_server
+app['http_server']='wsgiref' #使用的开发服务器 支持 wsgiref、kcweb、kcweb_server
 # redis配置
 redis={}
 redis['host']='127.0.0.1' #服务器地址
@@ -90,7 +90,7 @@ email['recNick']='' #默认收件人昵称
 
 kcweb={}
 kcweb['name']='kcweb'                             #项目的名称
-kcweb['version']='3.0.10'							#项目版本
+kcweb['version']='4.10.7'							#项目版本
 kcweb['description']=''       #项目的简单描述
 kcweb['long_description']=''     #项目详细描述
 kcweb['license']='MIT'                    #开源协议   mit开源
@@ -99,9 +99,14 @@ kcweb['author']='禄可集团-坤坤'  					 #名字
 kcweb['author_email']='fk1402936534@qq.com' 	     #邮件地址
 kcweb['maintainer']='坤坤' 						 #维护人员的名字
 kcweb['maintainer_email']='fk1402936534@qq.com'    #维护人员的邮件地址
+kcweb['username']=''
+kcweb['password']=''
 
 domain={}
 domain['kcwebfile']="http://file.kwebapp.cn"
+domain['kcwebstatic']="http://static.kwebapp.cn"
+domain['kcwebimg']="http://img.kwebapp.cn"
+domain['kcwebapi']="http://kcweb.kwebapp.cn"
 
 #其他配置
 other={}
