@@ -18,11 +18,20 @@ class mysql:
     __slaveidentifier='' # 从服务器标识
     def __del__(self):
         if not self.__config['pattern'] and self.__conn:
-            try:
+            if isinstance(self.__conn,dict):
+                i=0
+                for thost in self.__config['host']:
+                    identifier=thost+str(self.__config['port'][i])+self.__config['user'][i]+self.__config['password'][i]+self.__config['db'][i]
+                    for k in self.__conn[identifier]:
+                        try:
+                            k['obj'].close()
+                        except Exception as e:
+                            print(k,"连接关闭失败",str(e))
+                    i+=1
+                self.__conn={}
+            elif isinstance(self.__conn,object):
                 self.__conn.close()
-            except Exception as e:
-                if self.__config['debug']:
-                    print("关闭失败",e)
+                self.__conn={}
     __dbcount=1
     def __setdbcount(self):
         "设置数据库配置总数量"
@@ -63,11 +72,10 @@ class mysql:
         
         参数 typess ：数据查询语言DQL，数据操纵语言DML，数据定义语言DDL，数据控制语言DCL
         """
-
         try:
             if self.__config['deploy']==0: # 集中式(单一服务器)
                 if self.__config['pattern']: # 长连接情况下
-                    self.__masteridentifier=self.__config['host'][0]+str(self.__config['port'][0])+self.__config['db'][0] # 服务器标识
+                    self.__masteridentifier=self.__config['host'][0]+str(self.__config['port'][0])+self.__config['user'][0]+self.__config['password'][0]+self.__config['db'][0] # 服务器标识
                     if self.__masteridentifier not in mysql.__conn or len(mysql.__conn[self.__masteridentifier])<1:
                         i=0
                         masterlistsdb=[]
@@ -86,12 +94,12 @@ class mysql:
                     j=0
                     self.__masteridentifier=''
                     while j < self.__config['master_num']:
-                        self.__masteridentifier=self.__masteridentifier+self.__config['host'][j]+str(self.__config['port'][j])+self.__config['db'][j] # 主服务器标识
+                        self.__masteridentifier=self.__masteridentifier+self.__config['host'][j]+str(self.__config['port'][j])+self.__config['user'][j]+self.__config['password'][j]+self.__config['db'][j] # 主服务器标识
                         j=j+1
                     j=self.__config['master_num']
                     self.__slaveidentifier=''
                     while j < self.__dbcount:
-                        self.__slaveidentifier=self.__slaveidentifier+self.__config['host'][j]+str(self.__config['port'][j])+self.__config['db'][j] # 从服务器标识
+                        self.__slaveidentifier=self.__slaveidentifier+self.__config['host'][j]+str(self.__config['port'][j])+self.__config['user'][j]+self.__config['password'][j]+self.__config['db'][j] # 从服务器标识
                         j=j+1
                     if self.__masteridentifier not in mysql.__conn or len(mysql.__conn[self.__masteridentifier])<self.__config['master_num']:
                         j=0
@@ -349,7 +357,9 @@ class mysql:
                             except Exception as e:
                                 if self.__config['debug']:
                                     print("关闭异常",e)
-                        raise Exception(e)
+                            else:
+                                self.__connects(typess)
+                                self.__execute(typess)
                 else: # 短连接情况下
                     if self.__config['debug']:
                         print("服务器正在被关闭，关闭当前连接后重试")
