@@ -3,11 +3,11 @@ from .db import model
 from .db import sqlite as kcwsqlite
 import threading,time,os,hashlib,random
 queuesdbpath=os.path.split(os.path.realpath(__file__))[0]+"/Queues"
-class model_task(model.model):
+class model_kcweb_task(model.model):
     "任务"
     config={'type':'sqlite','db':queuesdbpath}
     model.dbtype.conf=config
-    table="Queues" 
+    table="model_kcweb_queues" 
     fields={
         "id":model.dbtype.int(LEN=11,PRI=True,A_L=True),        #设置id为自增主键
         "taskid":model.dbtype.varchar(LEN=32,DEFAULT=''),        #设置id为自增主键
@@ -23,32 +23,37 @@ class Queues():
     def start():
         if not Queues.__globalqueue:
             if not os.path.isfile(queuesdbpath):
-                tmondel=model_task()
-                tmondel.create_table()
+                model_kcweb_tasks=model_kcweb_task()
+                model_kcweb_tasks.create_table()
+            try:
+                kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").find()
+            except:
+                model_kcweb_tasks=model_kcweb_task()
+                model_kcweb_tasks.create_table()
             Queues.__globalqueue=Queue()
             t=threading.Thread(target=Queues.__messagequeue)
             t.daemon=True
             t.start()
     def __messagequeue():
-        kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").where("id","gt",0).delete()
+        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("1=1").delete()
         while True:
-            if not Queues.__globalqueue.empty(): 
+            if not Queues.__globalqueue.empty():
                 value=Queues.__globalqueue.get()
-                kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":3,"msg":"正在执行","error":""})
+                kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":3,"msg":"正在执行","error":""})
                 if value['args']:
                     try:
                         value['target'](*value['args'])
                     except Exception as e:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,"msg":"失败","error":str(e)})
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,"msg":"失败","error":str(e)})
                     else:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"msg":"执行完成"})
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"msg":"执行完成"})
                 else:
                     try:
                         value['target']()
                     except Exception as e:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,"msg":"失败","error":str(e)})
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,"msg":"失败","error":str(e)})
                     else:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"msg":"执行完成"})
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"msg":"执行完成"})
             else:
                 time.sleep(1)
     def insert(target,args=None,title="默认任务",describes="",msg='等待中'): #add_queue
@@ -71,8 +76,8 @@ class Queues():
         taskid=m.hexdigest()
         task={"taskid":taskid,"title":title,"describes":describes,"code":2,"msg":msg,"error":"","addtime":ttt}
         key={"target":target,"args":args,"task":task}
+        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").insert(task)
         Queues.__globalqueue.put(key)
-        kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").insert(task)
         return taskid
     def getall(code=''):
         """获取全部队列
@@ -82,14 +87,17 @@ class Queues():
         return list
         """
         if not os.path.isfile(queuesdbpath):
-            t=model_task()
-            t.create_table()
+            model_kcweb_tasks=model_kcweb_task()
+            model_kcweb_tasks.create_table()
         where=False
         if code:
-            where="code="+code
-        # else:
-        #     where="code!=4"
-        return kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").field("taskid,title,describes,code,msg,error,addtime").where(where).select()
+            where="code="+str(code)
+        try:
+            return kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").field("taskid,title,describes,code,msg,error,addtime").where(where).select()
+        except:
+            model_kcweb_tasks=model_kcweb_task()
+            model_kcweb_tasks.create_table()
+            return []
     def status(taskid):
         """获取任务状态
         
@@ -97,13 +105,13 @@ class Queues():
 
         return dict
         """
-        return kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").field("taskid,title,describes,code,msg,error,addtime").where("taskid",taskid).find()
+        return kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").field("taskid,title,describes,code,msg,error,addtime").where("taskid",taskid).find()
     def iscomplete():
         """判断对列中的任务是否全部执行完成
         
         return Boolean
         """
-        if kcwsqlite.sqlite().connect(queuesdbpath).table("Queues").where("code",3).count():
+        if kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("code",3).count():
             return True
         else:
             return False
